modeltree — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »

# modeltree

custom tree and tree-items widgets

class `camelot.view.controls.modeltree.` `ModelItem`(parent, columns_names, section_item)

  Custom tree item widget

class `camelot.view.controls.modeltree.` `ModelTree`(header_labels=[''], parent=None)

  Custom tree widget

  `mousePressEvent`(event)

    Custom context menu

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »

Comments
blog comments powered by Disqus